@@ -44,6 +44,8 @@ elif chip_id == ap_chip.T194:
     from adafruit_blinka.microcontroller.tegra.t194 import *
 elif chip_id == ap_chip.S905:
     from adafruit_blinka.microcontroller.amlogic.s905.pin import *
+elif chip_id == ap_chip.S922X:
+    from adafruit_blinka.microcontroller.amlogic.s922x.pin import *
 elif chip_id == ap_chip.APQ8016:
     from adafruit_blinka.microcontroller.snapdragon.apq8016.pin import *
 elif chip_id == ap_chip.IMX8MX:
